summaryrefslogtreecommitdiffstats
path: root/keduca/keduca/kradioeduca.h
diff options
context:
space:
mode:
Diffstat (limited to 'keduca/keduca/kradioeduca.h')
-rw-r--r--keduca/keduca/kradioeduca.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/keduca/keduca/kradioeduca.h b/keduca/keduca/kradioeduca.h
index b17276d9..f23c74a1 100644
--- a/keduca/keduca/kradioeduca.h
+++ b/keduca/keduca/kradioeduca.h
@@ -19,17 +19,17 @@
#define KRADIOEDUCA_H
#include <qradiobutton.h>
#include <qsimplerichtext.h>
/**QRadioButton with wordwrap and richtext features
*@author Javier Campos Morales
*/
-class KRadioEduca : public QRadioButton {
+class KRadioEduca : public TQRadioButton {
Q_OBJECT
public:
- KRadioEduca(QWidget *parent=0, const char *name=0);
+ KRadioEduca(TQWidget *parent=0, const char *name=0);
~KRadioEduca();
protected:
@@ -37,14 +37,14 @@ protected:
// Protected methods
/** reimpl */
- void drawButtonLabel( QPainter *p);
+ void drawButtonLabel( TQPainter *p);
private:
// Private attributes
/** Rich Text */
- QSimpleRichText *_doc;
+ TQSimpleRichText *_doc;
};
@@ -19,17 +19,17 @@
#define KRADIOEDUCA_H
-#include <qradiobutton.h>
-#include <qsimplerichtext.h>
+#include <tqradiobutton.h>
+#include <tqsimplerichtext.h>
-/**QRadioButton with wordwrap and richtext features
+/**TQRadioButton with wordwrap and richtext features
*@author Javier Campos Morales
*/